%define major      23
%define libname    %mklibname %{name} %{major}
%define develname  %mklibname %{name} -d
%define oldlibname %mklibname %{name}

Name:           openfst
Version:        1.8.0
Release:        %mkrel 7
Summary:        Library for managing weighted finite-state transducers
Group:          System/Libraries
License:        ASL 2.0
URL:            https://www.openfst.org
Source0:        https://www.openfst.org/twiki/pub/FST/FstDownload/openfst-%{version}.tar.gz
# from Fedora
Patch0:         openfst-1.8.3-gcc-fix.patch
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  gcc-c++
BuildRequires:  zlib-devel


%description
OpenFst is a library for constructing, combining, optimizing, and searching
weighted finite-state transducers (FSTs).
This version is adapted by alphacep for kaldi project.

%package -n %{libname}
Summary:        Main library for openfst
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}
Requires:       %{oldlibname}-extensions >= %{version}-%{release}
# libname was previously missing major number
Obsoletes:      %{oldlibname} < 1.8.0-4

%description -n %{libname}
OpenFst is a library for constructing, combining, optimizing, and searching
weighted finite-state transducers (FSTs).
This version is adapted by alphacep for kaldi project.

%package -n %{_lib}openfst-extensions
Summary:        Extension library for openfst
Group:          System/Libraries
Provides:       %{name}-extensions = %{version}-%{release}
# This file was previously in lib and devel package
Conflicts:      %{libname} < 1.8.0-5
Conflicts:      %{develname} < 1.8.0-4
# don't use major in its name
Obsoletes:      %{_lib}openfst23-extensions < 1.8.0-6

%description -n %{_lib}openfst-extensions
OpenFst is a library for constructing, combining, optimizing, and searching 
weighted finite-state transducers (FSTs).
This version is adapted by alphacep for kaldi project.
This package provides extension modules.


%package -n %{develname}
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{libname} = %{version}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains libraries and header files for
developing applications that use %{name}.


%prep
%autosetup -p1

%build
# compilation on 32 bit fails on this test : https://github.com/mjansche/openfst/blob/5be570c4e84a5eae1325d8c6c43fdbba3683863e/configure.ac#L155-183
# adding -msse2 -mfpmath=sse solves the compilation
autoreconf -fi
%ifarch aarch64
export CFLAGS="%{optflags} -flax-vector-conversions"
export CXXFLAGS="$CFLAGS"
%endif
# No more needed with i686 ?
#ifarch %ix86
# export CFLAGS="%{optflags} -msse2 -mfpmath=sse"
# export CXXFLAGS="$CFLAGS"
#endif
%configure --enable-static=no      \
           --enable-shared         \
           --enable-far            \
           --enable-ngram-fsts     \
           --enable-lookahead-fsts \
           --with-pic              \
           --disable-bin
%make_build

%install
%make_install


%files -n %{libname}
%license COPYING
%doc README
%{_libdir}/libfstfar.so.%{major}{,.*}
%{_libdir}/libfstlookahead.so.%{major}{,.*}
%{_libdir}/libfstngram.so.%{major}{,.*}
%{_libdir}/libfst.so.%{major}{,.*}

%files -n %{_lib}openfst-extensions
%license COPYING
%doc README
%dir %{_libdir}/fst
%{_libdir}/fst/*.so

%files -n %{develname}
%license COPYING
%doc README
%{_includedir}/*
%{_libdir}/*.so


%changelog
* Fri Aug 30 2024 papoteur <papoteur> 1.8.0-7.mga10
+ Revision: 2092301
- fix release of extensions lib to obsolete

* Fri Aug 30 2024 papoteur <papoteur> 1.8.0-6.mga10
+ Revision: 2092223
- reverse to 1.8.0
- kaldi from alphaceip is not ready for newer version

* Wed Jun 26 2024 papoteur <papoteur> 1.8.3-3.mga10
+ Revision: 2076914
- fix obsoleting version for majored lib extensions

* Wed Jun 26 2024 papoteur <papoteur> 1.8.3-2.mga10
+ Revision: 2076863
- rename extensions package without major number

* Tue Jun 25 2024 papoteur <papoteur> 1.8.3-1.mga10
+ Revision: 2076680
- new version 1.8.3

* Sun Jan 01 2023 daviddavid <daviddavid> 1.8.0-5.mga9
+ Revision: 1928713
- really separating fst/*.so libs in -extensions sub pkg
- own lib dir fst

* Sun Jun 26 2022 papoteur <papoteur> 1.8.0-4.mga9
+ Revision: 1866315
- Adding -extensions package for separating fst/*.so

* Sun Jun 26 2022 papoteur <papoteur> 1.8.0-3.mga9
+ Revision: 1866304
- better place for fst/*.so files

* Sun Jun 12 2022 papoteur <papoteur> 1.8.0-2.mga9
+ Revision: 1864073
- Use major number for library name

* Sat Jun 11 2022 papoteur <papoteur> 1.8.0-1.mga9
+ Revision: 1863967
- imported package openfst

